| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Inspector2.Types.DateFilter
Description
Synopsis
Documentation
data DateFilter Source #
Contains details on the time range used to filter findings.
See: newDateFilter smart constructor.
Constructors
| DateFilter' | |
Fields
| |
Instances
newDateFilter :: DateFilter Source #
Create a value of DateFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:endInclusive:DateFilter', dateFilter_endInclusive - A timestamp representing the end of the time period filtered on.
$sel:startInclusive:DateFilter', dateFilter_startInclusive - A timestamp representing the start of the time period filtered on.
dateFilter_endInclusive :: Lens' DateFilter (Maybe UTCTime) Source #
A timestamp representing the end of the time period filtered on.
dateFilter_startInclusive :: Lens' DateFilter (Maybe UTCTime) Source #
A timestamp representing the start of the time period filtered on.