| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Inspector2.Types.Filter
Description
Synopsis
- data Filter = Filter' {}
- newFilter :: FilterAction -> Text -> UTCTime -> FilterCriteria -> Text -> Text -> UTCTime -> Filter
- filter_description :: Lens' Filter (Maybe Text)
- filter_reason :: Lens' Filter (Maybe Text)
- filter_tags :: Lens' Filter (Maybe (HashMap Text Text))
- filter_action :: Lens' Filter FilterAction
- filter_arn :: Lens' Filter Text
- filter_createdAt :: Lens' Filter UTCTime
- filter_criteria :: Lens' Filter FilterCriteria
- filter_name :: Lens' Filter Text
- filter_ownerId :: Lens' Filter Text
- filter_updatedAt :: Lens' Filter UTCTime
Documentation
Details about a filter.
See: newFilter smart constructor.
Constructors
| Filter' | |
Fields
| |
Instances
Arguments
| :: FilterAction | |
| -> Text | |
| -> UTCTime | |
| -> FilterCriteria | |
| -> Text | |
| -> Text | |
| -> UTCTime | |
| -> Filter |
Create a value of Filter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:description:Filter', filter_description - A description of the filter.
$sel:reason:Filter', filter_reason - The reason for the filter.
$sel:tags:Filter', filter_tags - The tags attached to the filter.
$sel:action:Filter', filter_action - The action that is to be applied to the findings that match the filter.
$sel:arn:Filter', filter_arn - The Amazon Resource Number (ARN) associated with this filter.
$sel:createdAt:Filter', filter_createdAt - The date and time this filter was created at.
$sel:criteria:Filter', filter_criteria - Details on the filter criteria associated with this filter.
$sel:name:Filter', filter_name - The name of the filter.
$sel:ownerId:Filter', filter_ownerId - The Amazon Web Services account ID of the account that created the
filter.
Filter, filter_updatedAt - The date and time the filter was last updated at.
filter_action :: Lens' Filter FilterAction Source #
The action that is to be applied to the findings that match the filter.
filter_arn :: Lens' Filter Text Source #
The Amazon Resource Number (ARN) associated with this filter.
filter_criteria :: Lens' Filter FilterCriteria Source #
Details on the filter criteria associated with this filter.