| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Inspector2.Types.InspectorScoreDetails
Description
Documentation
data InspectorScoreDetails Source #
Information about the Amazon Inspector score given to a finding.
See: newInspectorScoreDetails smart constructor.
Constructors
| InspectorScoreDetails' | |
Fields
| |
Instances
newInspectorScoreDetails :: InspectorScoreDetails Source #
Create a value of InspectorScoreDetails with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:adjustedCvss:InspectorScoreDetails', inspectorScoreDetails_adjustedCvss - An object that contains details about the CVSS score given to a finding.
inspectorScoreDetails_adjustedCvss :: Lens' InspectorScoreDetails (Maybe CvssScoreDetails) Source #
An object that contains details about the CVSS score given to a finding.