| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Inspector2.Types.MapFilter
Description
Synopsis
- data MapFilter = MapFilter' {
- value :: Maybe Text
- comparison :: MapComparison
- key :: Text
- newMapFilter :: MapComparison -> Text -> MapFilter
- mapFilter_value :: Lens' MapFilter (Maybe Text)
- mapFilter_comparison :: Lens' MapFilter MapComparison
- mapFilter_key :: Lens' MapFilter Text
Documentation
An object that describes details of a map filter.
See: newMapFilter smart constructor.
Constructors
| MapFilter' | |
Fields
| |
Instances
| FromJSON MapFilter Source # | |
| ToJSON MapFilter Source # | |
Defined in Amazonka.Inspector2.Types.MapFilter | |
| Generic MapFilter Source # | |
| Read MapFilter Source # | |
| Show MapFilter Source # | |
| NFData MapFilter Source # | |
Defined in Amazonka.Inspector2.Types.MapFilter | |
| Eq MapFilter Source # | |
| Hashable MapFilter Source # | |
Defined in Amazonka.Inspector2.Types.MapFilter | |
| type Rep MapFilter Source # | |
Defined in Amazonka.Inspector2.Types.MapFilter type Rep MapFilter = D1 ('MetaData "MapFilter" "Amazonka.Inspector2.Types.MapFilter" "amazonka-inspector2-2.0-EI0CfxGdACSBWwvVde8cFy" 'False) (C1 ('MetaCons "MapFilter'" 'PrefixI 'True) (S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)) :*: (S1 ('MetaSel ('Just "comparison") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 MapComparison) :*: S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Text)))) | |
Arguments
| :: MapComparison | |
| -> Text | |
| -> MapFilter |
Create a value of MapFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:value:MapFilter', mapFilter_value - The tag value used in the filter.
$sel:comparison:MapFilter', mapFilter_comparison - The operator to use when comparing values in the filter.
$sel:key:MapFilter', mapFilter_key - The tag key used in the filter.
mapFilter_comparison :: Lens' MapFilter MapComparison Source #
The operator to use when comparing values in the filter.