| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Inspector2.Types.SortCriteria
Description
Synopsis
Documentation
data SortCriteria Source #
Details about the criteria used to sort finding results.
See: newSortCriteria smart constructor.
Constructors
| SortCriteria' | |
Instances
Arguments
| :: SortField | |
| -> SortOrder | |
| -> SortCriteria |
Create a value of SortCriteria with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:field:SortCriteria', sortCriteria_field - The finding detail field by which results are sorted.
$sel:sortOrder:SortCriteria', sortCriteria_sortOrder - The order by which findings are sorted.
sortCriteria_field :: Lens' SortCriteria SortField Source #
The finding detail field by which results are sorted.
sortCriteria_sortOrder :: Lens' SortCriteria SortOrder Source #
The order by which findings are sorted.