| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Inspector2.Types.StringFilter
Description
Synopsis
Documentation
data StringFilter Source #
An object that describes the details of a string filter.
See: newStringFilter smart constructor.
Constructors
| StringFilter' | |
Fields
| |
Instances
Arguments
| :: StringComparison | |
| -> Text | |
| -> StringFilter |
Create a value of StringFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:comparison:StringFilter', stringFilter_comparison - The operator to use when comparing values in the filter.
$sel:value:StringFilter', stringFilter_value - The value to filter on.
stringFilter_comparison :: Lens' StringFilter StringComparison Source #
The operator to use when comparing values in the filter.
stringFilter_value :: Lens' StringFilter Text Source #
The value to filter on.